==> glibc-2.2.3.tar.gz: glibc-2.2.3/sysdeps/s390/s390-64/__longjmp.c <==
/* Copyright (C) 2001 Free Software Foundation, Inc.
   This file is part of the GNU C Library.
   Contributed by Martin Schwidefsky (schwidefsky@de.ibm.com).

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the GNU C Library; see the file COPYING.LIB.  If not,
   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

#include <errno.h>
#include <sysdep.h>
#include <setjmp.h>
#include <bits/setjmp.h>
#include <stdlib.h>
#include <unistd.h>

/* Jump to the position specified by ENV, causing the
   setjmp call there to return VAL, or 1 if VAL is 0.  */
void
__longjmp (__jmp_buf env, int val)
{
   /* Restore registers and jump back.  */
   asm volatile ("lgr  %%r2,%0\n\t"        /* Put val in grp 2.  */
		 "ld   %%f7,104(%1)\n\t"
		 "ld   %%f5,96(%1)\n\t"
		 "ld   %%f3,88(%1)\n\t"
		 "ld   %%f1,80(%1)\n\t"
                 "lmg  %%r6,%%r15,0(%1)\n\t"
                 "br   %%r14"
                 : : "r" (val == 0 ? 1 : val),
                 "a" (env) : "2" );

  /* Avoid `volatile function does return' warnings.  */
  for (;;);
}

==> glibc-2.3.2.tar.gz: glibc-2.3.2/sysdeps/s390/s390-64/__longjmp.c <==
/* Copyright (C) 2001 Free Software Foundation, Inc.
   This file is part of the GNU C Library.
   Contributed by Martin Schwidefsky (schwidefsky@de.ibm.com).

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
   02111-1307 USA.  */

#include <errno.h>
#include <sysdep.h>
#include <setjmp.h>
#include <bits/setjmp.h>
#include <stdlib.h>
#include <unistd.h>

/* Jump to the position specified by ENV, causing the
   setjmp call there to return VAL, or 1 if VAL is 0.  */
void
__longjmp (__jmp_buf env, int val)
{
   /* Restore registers and jump back.  */
   asm volatile ("lgr  %%r2,%0\n\t"        /* Put val in grp 2.  */
		 "ld   %%f7,104(%1)\n\t"
		 "ld   %%f5,96(%1)\n\t"
		 "ld   %%f3,88(%1)\n\t"
		 "ld   %%f1,80(%1)\n\t"
                 "lmg  %%r6,%%r15,0(%1)\n\t"
                 "br   %%r14"
                 : : "r" (val == 0 ? 1 : val),
                 "a" (env) : "2" );

  /* Avoid `volatile function does return' warnings.  */
  for (;;);
}
